@@ -349,6 +349,25 @@ def get_test_control_group_data() -> List[Tuple[List[str], dict]]:
                 % get_configured_value("cli_testing.local_network"),
             },
         ),
+        (
+            ["--collection-preferred-origin"],
+            {
+                "dest": "collection.preferred_status_origin",
+                "type": str,
+                "choices": ["frequent", "latest", "recommended"],
+                "help": "Sets the preferred status origin. %s"
+                % get_configured_value("collection.preferred_status_origin"),
+            },
+        ),
+        (
+            ["--collection-lookup"],
+            {
+                "dest": "lookup.collection",
+                "action": "store_true",
+                "help": "Activates or disables the usage of the Collection lookup\n"
+                "whether possible. %s" % get_configured_value("lookup.collection"),
+            },
+        ),
         (
             ["--dns-lookup"],
             {
@@ -822,6 +841,17 @@ def get_output_control_group_data() -> List[Tuple[List[str], dict]]:
                 "help": argparse.SUPPRESS,
             },
         ),
+        (
+            [
+                "--push-collection",
+            ],
+            {
+                "dest": "collection.push",
+                "action": "store_true",
+                "help": "Activates or disables the push of test result into the\n"
+                "collection API. %s" % get_configured_value("collection.push"),
+            },
+        ),
         (
             [
                 "-s",
